==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/space/messages/hu/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Ez a közösség még üres!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Ez a közösség még üres!</b><br>Írd meg te az első bejegyzést...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Nem vagy tagja a közösségnek, és még nincs itt nyilvános tartalom!</b>',
    '<strong>About</strong> the Space' => 'Közösségről <strong>bővebben</strong>',
    '<strong>About</strong> your membership' => 'Tagságodról <strong>bővebben</strong>',
    '<strong>Confirm</strong> image deletion' => 'Kép törlésének <strong>megerősítése</strong>',
    '<strong>Invite</strong> members' => 'Tagok <strong>meghívása</strong>',
    '<strong>New</strong> member request' => '<strong>Új</strong> tagságkérelmek',
    '<strong>New</strong> spaces' => '<strong>Új</strong> közösségek',
    '<strong>Request</strong> space membership' => 'Tagság <strong>kérelmezése</strong> a közösségben',
    '<strong>Space</strong> followers' => '<strong>Közösség</strong> követői',
    '<strong>Space</strong> members' => '<strong>Közösség</strong> tagjai',
    '<strong>Space</strong> menu' => '<strong>Közösség</strong> menü',
    'About' => 'Rólunk',
    'Accept' => 'Elfogadás',
    'Accept Invite' => 'Meghívó elfogadása',
    'Add users without invitation' => 'Tagok hozzáadása meghívás nélkül',
    'Admin' => 'Admin',
    'Administrator:' => 'Adminisztrátor:',
    'Administrators' => 'Adminisztrátorok',
    'Application message' => 'Alkalmazás üzenet',
    'Archived' => 'Archiválva',
    'As owner you cannot revoke your membership!' => 'Tulajdonosként nem vonhatod vissza a tagságodat!',
    'Cancel' => 'Mégsem',
    'Close' => 'Bezár',
    'Color' => 'Szín',
    'Could not request membership!' => 'Nem lehetett tagságot igényelni.',
    'Created At' => 'Létrejött',
    'Created By' => 'Létrehozta',
    'Decline' => 'Elutasít',
    'Decline Invite' => 'Meghívás elutasítása',
    'Default' => 'Alapértelmezett',
    'Default content visibility' => 'Alapértelmezett tartalom megjelenítés',
    'Delete' => 'Törlés',
    'Description' => 'Leírás',
    'Do you really want to delete your profile image?' => 'Biztos, hogy törölni szeretnéd a profilképedet?',
    'Do you really want to delete your title image?' => 'Biztos, hogy törölni szeretnéd a fejlécképedet?',
    'Done' => 'Kész',
    'Email addresses' => 'E-mail címek',
    'Everyone can enter' => 'Bárki beléphet',
    'Follow' => 'Követés',
    'Followers' => 'Követők',
    'Following' => 'Követve',
    'Guests' => 'Vendégek',
    'Hide Members sidebar in the stream page.' => 'A tagok oldalsávjának elrejtése a hírfolyamban.',
    'Homepage' => 'Kezdőlap',
    'Homepage (Guests)' => 'Kezdőlap (vendég)',
    'Invite' => 'Meghívás',
    'Invite and request' => 'Meghívás és jelentkezés',
    'Invite by email' => 'Meghívás e-mailben',
    'Invites' => 'Meghívások',
    'Join' => 'Csatlakozás',
    'Join Policy' => 'Csatlakozási irányelv',
    'Last Visit' => 'Utolsó látogatás',
    'Login' => 'Bejelentkezés',
    'Max. 100 characters.' => 'Max. 100 karakter.',
    'Member since' => 'Tagság kezdete',
    'Members' => 'Tagok',
    'Moderator' => 'Moderátor',
    'Moderator:' => 'Moderátor:',
    'Moderators' => 'Moderátorok',
    'My Space List' => 'Saját közösségem listája',
    'My space summary' => 'Saját közösségeim összesítése',
    'Name' => 'Név',
    'New user by e-mail (comma separated)' => 'Új felhasználó e-maillel (vesszővel elválasztva)',
    'New user?' => 'Új felhasználó?',
    'No results found!' => 'Nincs találat!',
    'No spaces found.' => 'Nem található közösség.',
    'Only by invite' => 'Csak meghívással',
    'Originator User ID' => 'Kezdeményező azonosítója',
    'Owner' => 'Tulajdonos',
    'Owner:' => 'Tulajdonos:',
    'Pending' => 'Függőben',
    'Pick users' => 'Felhasználók kiválasztása',
    'Please shortly introduce yourself, to become an approved member of this space.' => 'Kérjük, mutatkozz be röviden, hogy taggá válhass ebben a közösségben.',
    'Posts' => 'Bejegyzések',
    'Private' => 'Zárt',
    'Private (Invisible)' => 'Zárt (nem látható)',
    'Public' => 'Nyilvános',
    'Public (Members & Guests)' => 'Nyilvános (tagok és vendégek)',
    'Public (Members only)' => 'Nyilvános (csak tagoknak)',
    'Public (Registered users only)' => 'Nyilvános (csak regisztrált felhasználóknak)',
    'Request Message' => 'Üzenet kérése',
    'Role' => 'Szerepkör',
    'See all' => 'Összes',
    'Select all registered users' => 'Összes regisztrált tag kiválasztása',
    'Send' => 'Küldés',
    'Settings' => 'Beállítások',
    'Settings could not be saved!' => 'A beállításokat nem sikerült menteni!',
    'Show all' => 'Összes mutatása',
    'Shown on About Page.' => 'A Rólunk oldalon látható',
    'Sorry, you are not allowed to leave this space!' => 'Elnézést, nem vagy jogosult a közösség elhagyására.',
    'Sorting' => 'Rendezés',
    'Space' => 'Közösség',
    'Space Visibility' => 'Közösség láthatósága',
    'Space directory' => 'Közösség lista',
    'Space is invisible!' => 'Közösség nem látható!',
    'Spaces' => 'Közösségek',
    'Status' => 'Állapot',
    'Stream' => 'Hírfolyam',
    'Tags' => 'Címkék',
    'There is no pending invite!' => 'Nincsenek függőben meghívások.',
    'This action is only available for workspace members!' => 'Ez a funkció csak tagok részére elérhető.',
    'This user is already a member of this space.' => 'Ez a felhasználó már tagja ennek a közösségnek.',
    'This user is not a member of this space.' => 'Ez a felhasználó nem tagja ennek a közösségnek.',
    'To invite users to this space, please type their names below to find and pick them.' => 'Ha felhasználókat szeretnél meghívni a közösségbe, gépeld be a nevüket lent és válaszd ki őket.',
    'Updated At' => 'Frissítve',
    'Updated By' => 'Frissítette',
    'Updated by' => 'Frissítette',
    'User \'{username}\' is already a member of this space!' => '\'{username}\' felhasználó már tagja ennek a közösségnek!',
    'User invitations have been added to the queue' => 'Felhasználói meghívások kerültek várólistára',
    'User memberships have been added to the queue' => 'Felhasználói tagsági kérelmek kerültek várólistára',
    'User not found!' => 'Felhasználó nem található!',
    'Users' => 'Felhasználók',
    'Users has been invited.' => 'A felhasználó meghívást kapott.',
    'Visibility' => 'Láthatóság',
    'Visible for all (members and guests)' => 'Mindenki számára látható (tagok és vendégek)',
    'You are not allowed to join this space!' => 'Nem csatlakozhatsz ehhez a közösséghez!',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Meghívhatsz nem regisztrált felhasználókat is. Add meg e-mail címüket, vesszővel elválasztva.',
    'You cannot create private visible spaces!' => 'Nem hozhatsz létre zárt közösségeket!',
    'You cannot create public visible spaces!' => 'Nem hozhatsz létre nyilvános közösségeket!',
    'You need to login to view contents of this space!' => 'A közösségbeli tartalmak megtekintéséhez be kell jelentkezned!',
    'Your request was successfully submitted to the space administrators.' => 'A kérelmedet sikeresen rögzítettük és továbbítottuk a közösség adminisztrátorainak.',
    '{count} members' => '{count} tag',
    '{email} is not valid!' => '{email} cím érvénytelen!',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Find Spaces by their description or by their tags' => '',
    'Member' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'Oldest first' => '',
    'Search...' => '',
    'Try other keywords or remove filters.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
];

==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/space/messages/hu/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Ez a közösség még üres!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Ez a közösség még üres!</b><br>Írd meg te az első bejegyzést...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Nem vagy tagja a közösségnek, és még nincs itt nyilvános tartalom!</b>',
    '<strong>About</strong> the Space' => 'Közösségről <strong>bővebben</strong>',
    '<strong>About</strong> your membership' => 'Tagságodról <strong>bővebben</strong>',
    '<strong>Confirm</strong> image deletion' => 'Kép törlésének <strong>megerősítése</strong>',
    '<strong>Invite</strong> members' => 'Tagok <strong>meghívása</strong>',
    '<strong>Leave</strong> Space' => '<strong>Kilépés</strong> a Közösségből',
    '<strong>New</strong> member request' => '<strong>Új</strong> tagságkérelmek',
    '<strong>New</strong> spaces' => '<strong>Új</strong> közösségek',
    '<strong>Request</strong> Membership' => 'Tagság <strong>kérelmezése</strong> a közösségben',
    '<strong>Space</strong> followers' => '<strong>Közösség</strong> követői',
    '<strong>Space</strong> members' => '<strong>Közösség</strong> tagjai',
    '<strong>Space</strong> menu' => '<strong>Közösség</strong> menü',
    '<strong>Space</strong> tags' => '<strong>Space</strong> címkék',
    '<strong>Spaces</strong>' => '<strong>Közösségek</strong>',
    'About' => 'Rólunk',
    'Accept' => 'Elfogadás',
    'Accept Invite' => 'Meghívó elfogadása',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Kérjük, mutatkozz be röviden, hogy taggá válhass ebben a közösségben.',
    'Add users without invitation' => 'Tagok hozzáadása meghívás nélkül',
    'Admin' => 'Admin',
    'Administrator:' => 'Adminisztrátor:',
    'Administrators' => 'Adminisztrátorok',
    'Any' => 'Bármi',
    'Archived' => 'Archiválva',
    'As owner you cannot revoke your membership!' => 'Tulajdonosként nem vonhatod vissza a tagságodat!',
    'Blocked users' => 'Letiltott felhasználók',
    'By Name' => 'Név szerint',
    'Cancel' => 'Mégsem',
    'Change visibility' => 'A láthatóság módosítása',
    'Close' => 'Bezár',
    'Color' => 'Szín',
    'Could not request membership!' => 'Nem lehetett tagságot igényelni.',
    'Create new link' => 'Új link létrehozása',
    'Created At' => 'Létrejött',
    'Created By' => 'Létrehozta',
    'Decline' => 'Elutasít',
    'Decline Invite' => 'Meghívás elutasítása',
    'Default' => 'Alapértelmezett',
    'Default content visibility' => 'Alapértelmezett tartalom megjelenítés',
    'Delete' => 'Törlés',
    'Description' => 'Leírás',
    'Do you really want to delete your profile image?' => 'Biztos, hogy törölni szeretnéd a profilképedet?',
    'Do you really want to delete your title image?' => 'Biztos, hogy törölni szeretnéd a fejlécképedet?',
    'Done' => 'Kész',
    'Email addresses' => 'E-mail címek',
    'Everyone can enter' => 'Bárki beléphet',
    'Find Spaces by their description or by their tags' => 'Keresd meg a Közösséget leírásuk vagy címkéik alapján',
    'Follow' => 'Követés',
    'Followers' => 'Követők',
    'Following' => 'Követve',
    'Guests' => 'Vendégek',
    'Hide About Page' => 'A Rólunk oldal elrejtése',
    'Hide Activity Sidebar Widget' => 'Tevékenység oldalsáv widget elrejtése',
    'Hide Followers' => 'Követők elrejtése',
    'Hide Members' => 'Tagok elrejtése',
    'Homepage' => 'Kezdőlap',
    'Homepage (Non-members)' => 'Kezdőlap (nem tagok)',
    'I want to become a member because...' => 'Szeretnék tag lenni, mert...',
    'Incorrect name, try again.' => 'Hibás név, próbálkozzon újra.',
    'Invite' => 'Meghívás',
    'Invite and request' => 'Meghívás és jelentkezés',
    'Invite by email' => 'Meghívás e-mailben',
    'Invite by link' => 'Meghívás linken keresztül',
    'Invite link' => 'Meghívó link',
    'Invites' => 'Meghívások',
    'Join' => 'Csatlakozás',
    'Join Policy' => 'Csatlakozási irányelv',
    'Last Visit' => 'Utolsó látogatás',
    'Leave' => 'Elhagyás',
    'Login' => 'Bejelentkezés',
    'Max. 100 characters.' => 'Max. 100 karakter.',
    'Member' => 'Tag',
    'Member since' => 'Tagság kezdete',
    'Members' => 'Tagok',
    'Moderator' => 'Moderátor',
    'Moderator:' => 'Moderátor:',
    'Moderators' => 'Moderátorok',
    'My Space List' => 'Saját közösségem listája',
    'My space summary' => 'Saját közösségeim összesítése',
    'Name' => 'Név',
    'Name / Sort order' => 'Név / Rendezési sorrend',
    'Neither..nor' => 'Sem..sem',
    'New user by e-mail (comma separated)' => 'Új felhasználó e-maillel (vesszővel elválasztva)',
    'New user?' => 'Új felhasználó?',
    'Newest first' => 'Először a legújabb',
    'No results found!' => 'Nincs találat!',
    'No spaces found.' => 'Nem található közösség.',
    'Oldest first' => 'Először a legrégebbi',
    'Only by invite' => 'Csak meghívással',
    'Originator User ID' => 'Kezdeményező azonosítója',
    'Owner' => 'Tulajdonos',
    'Owner:' => 'Tulajdonos:',
    'Pending' => 'Függőben',
    'Pick users' => 'Felhasználók kiválasztása',
    'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => 'Kérjük, vegye figyelembe, hogy a korábban létrehozott linkek érvénytelenné válnak, amint új linket hoz létre. Szeretné folytatni?',
    'Posts' => 'Bejegyzések',
    'Private' => 'Zárt',
    'Private (Invisible)' => 'Zárt (nem látható)',
    'Public' => 'Nyilvános',
    'Public (Members & Guests)' => 'Nyilvános (tagok és vendégek)',
    'Public (Members only)' => 'Nyilvános (csak tagoknak)',
    'Public (Registered users only)' => 'Nyilvános (csak regisztrált felhasználóknak)',
    'Request Message' => 'Üzenet kérése',
    'Role' => 'Szerepkör',
    'Search...' => 'Keresés...',
    'See all' => 'Összes',
    'Select all registered users' => 'Összes regisztrált tag kiválasztása',
    'Send' => 'Küldés',
    'Send the link via email' => 'Küldje el a linket e-mailben',
    'Settings' => 'Beállítások',
    'Settings could not be saved!' => 'A beállításokat nem sikerült menteni!',
    'Show all' => 'Összes mutatása',
    'Show as List' => 'Megjelenítés listaként',
    'Shown on About Page.' => 'A Rólunk oldalon látható',
    'Sorry, you are not allowed to leave this space!' => 'Elnézést, nem vagy jogosult a közösség elhagyására.',
    'Sorting' => 'Rendezés',
    'Space' => 'Közösség',
    'Space Name' => 'Közösség Neve',
    'Space Visibility' => 'Közösség láthatósága',
    'Space directory' => 'Közösség lista',
    'Space is invisible!' => 'Közösség nem látható!',
    'Spaces' => 'Közösségek',
    'Status' => 'Állapot',
    'Stream' => 'Hírfolyam',
    'Tags' => 'Címkék',
    'The default homepage for members of this Space' => 'A tér tagjainak alapértelmezett kezdőlapja',
    'The default homepage for non-members and guests visiting this Space' => 'A nem tagok és a teret meglátogató vendégek alapértelmezett kezdőlapja',
    'The secure link has been copied in your clipboard!' => 'A biztonságos linket a vágólapra másolta!',
    'There is no pending invite!' => 'Nincsenek függőben meghívások.',
    'This action is only available for workspace members!' => 'Ez a funkció csak tagok részére elérhető.',
    'This user is already a member of this space.' => 'Ez a felhasználó már tagja ennek a közösségnek.',
    'This user is not a member of this space.' => 'Ez a felhasználó nem tagja ennek a közösségnek.',
    'To invite users to this space, please type their names below to find and pick them.' => 'Ha felhasználókat szeretnél meghívni a közösségbe, gépeld be a nevüket lent és válaszd ki őket.',
    'Try other keywords or remove filters.' => 'Próbálj ki más kulcsszavakat, vagy távolítsd el a szűrőket.',
    'Updated At' => 'Frissítve',
    'Updated By' => 'Frissítette',
    'Updated by' => 'Frissítette',
    'User \'{username}\' is already a member of this space!' => '\'{username}\' felhasználó már tagja ennek a közösségnek!',
    'User invitations have been added to the queue' => 'Felhasználói meghívások kerültek várólistára',
    'User memberships have been added to the queue' => 'Felhasználói tagsági kérelmek kerültek várólistára',
    'User not found!' => 'Felhasználó nem található!',
    'Users' => 'Felhasználók',
    'Users has been invited.' => 'A felhasználó meghívást kapott.',
    'Visibility' => 'Láthatóság',
    'Visible for all (members and guests)' => 'Mindenki számára látható (tagok és vendégek)',
    'Warning: If you change the visibility settings of a Space from public to private, all content within that Space, including posts, comments, attachments etc. will also be set to private. This means that non-members will no longer be able to see, access, or interact with any of the content within that Space.' => 'Figyelmeztetés: Ha egy tér láthatósági beállításait nyilvánosról privátra módosítja, a téren belüli összes tartalom, beleértve a bejegyzéseket, megjegyzéseket, mellékleteket stb., szintén privátra lesz állítva. Ez azt jelenti, hogy a tagsággal nem rendelkező személyek többé nem láthatják, nem érhetik el a Tér tartalmát, és nem léphetnek kapcsolatba velük.',
    'Would you like to end your membership in Space {spaceName}?' => 'Szeretnéd megszüntetni tagságodat a(z) {spaceName} közösségben?',
    'Would you like to unfollow Space {spaceName}?' => 'Szeretnéd leállítani a(z) {spaceName} közösség követését?',
    'Would you like to unfollow {userName}?' => 'Szeretnéd megszüntetni {userName} követését?',
    'Would you like to withdraw your request to join Space {spaceName}?' => 'Szeretnéd visszavonni a(z) {spaceName} közösséghez való csatlakozási kérelmedet?',
    'You are not allowed to join this space!' => 'Nem csatlakozhatsz ehhez a közösséghez!',
    'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Külső felhasználókat is meghívhat e-mailben, akik még nem regisztráltak. Csak adja hozzá az e-mail címüket vesszővel elválasztva.',
    'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => 'A linken keresztül meghívhat külső felhasználókat, akik jelenleg nem regisztráltak. Csak annyit kell tennie, hogy megosztja velük ezt a biztonságos linket.',
    'You cannot create private visible spaces!' => 'Nem hozhatsz létre zárt közösségeket!',
    'You cannot create public visible spaces!' => 'Nem hozhatsz létre nyilvános közösségeket!',
    'You need to login to view contents of this space!' => 'A közösségbeli tartalmak megtekintéséhez be kell jelentkezned!',
    'Your Message' => 'Alkalmazás üzenet',
    'Your request was successfully submitted to the space administrators.' => 'A kérelmedet sikeresen rögzítettük és továbbítottuk a közösség adminisztrátorainak.',
    '{count} members' => '{count} tag',
    '{email} is not valid!' => '{email} cím érvénytelen!',
    'Advanced Spaces Search' => '',
];
